import { StrictMode } from 'react'
import { createRoot } from 'react-dom/client'
import { createBrowserRouter, RouterProvider } from 'react-router-dom'
import React, { Suspense } from 'react'
import './index.css'
import './theme.css'
import './styles/Responsive.css'
import App from './App.jsx'
import { Toaster } from 'react-hot-toast';
import ProtectedRoute from './components/ProtectedRoute';
import Loader from './components/Loader';

// Dynamic wrapper for protected routes
const ProtectedOrdersRoute = () => {
  const isAuthenticated = localStorage.getItem('userId') !== null;
  const isFollowing = localStorage.getItem('isFollowing') === 'true';
  
  return (
    <ProtectedRoute
      isAuthenticated={isAuthenticated}
      isFollowing={isFollowing}
      requiresWhitelist={true}
    >
      <Suspense fallback={<PageLoader />}>
        <Orders />
      </Suspense>
    </ProtectedRoute>
  );
};

// Lazy load route components
const LandingPage = React.lazy(() => import('./pages/LandingPage'));
const Demande = React.lazy(() => import('./pages/Demande'));
const Orders = React.lazy(() => import('./pages/Orders'));
const TwitchCallback = React.lazy(() => import('./pages/TwitchCallback'));
const Tutorial = React.lazy(() => import('./pages/Tutorial'));
const Almanax = React.lazy(() => import('./pages/Almanax'));
const MentionsLegales = React.lazy(() => import('./pages/MentionsLegales'));
const PolitiqueConfidentialite = React.lazy(() => import('./pages/PolitiqueConfidentialite'));
const NotFound = React.lazy(() => import('./pages/NotFound'));
// Tool pages
const ToolPage = React.lazy(() => import('./pages/ToolPage'));

// Loading fallback component
const PageLoader = () => <div style={{ padding: '20px' }}><Loader fullPage text="Chargement de la page..." /></div>;

const router = createBrowserRouter([{
  path: '/',
  element: (
    <>
      <Toaster />
      <App />
    </>
  ),
  children: [
    {
      path: 'demande',
      element: (
        <Suspense fallback={<PageLoader />}>
          <Demande />
        </Suspense>
      )
    },
    { 
      path: 'orders', 
      element: <ProtectedOrdersRoute />
    },
    { 
      path: 'callback', 
      element: (
        <Suspense fallback={<PageLoader />}>
          <TwitchCallback />
        </Suspense>
      ) 
    },
    { 
      path: 'auth-complete', 
      element: (
        <Suspense fallback={<PageLoader />}>
          <TwitchCallback />
        </Suspense>
      ) 
    },
    { 
      path: 'tutorial', 
      element: (
        <Suspense fallback={<PageLoader />}>
          <Tutorial />
        </Suspense>
      ) 
    },
    { 
      path: 'almanax', 
      element: (
        <Suspense fallback={<PageLoader />}>
          <Almanax />
        </Suspense>
      ) 
    },
    { 
      path: 'mentions-legales', 
      element: (
        <Suspense fallback={<PageLoader />}>
          <MentionsLegales />
        </Suspense>
      ) 
    },
    { 
      path: 'politique-de-confidentialite', 
      element: (
        <Suspense fallback={<PageLoader />}>
          <PolitiqueConfidentialite />
        </Suspense>
      ) 
    },
    { 
      path: 'tools/:toolId', 
      element: (
        <Suspense fallback={<PageLoader />}>
          <ToolPage />
        </Suspense>
      ) 
    },
    { 
      path: '', 
      element: (
        <Suspense fallback={<PageLoader />}>
          <LandingPage />
        </Suspense>
      ) 
    },
    {
      path: '*',
      element: (
        <Suspense fallback={<PageLoader />}>
          <NotFound />
        </Suspense>
      )
    }
  ]
}], {
  future: {
    v7_startTransition: true,
    v7_relativeSplatPath: true
  }
})

// Register service worker for video caching
if ('serviceWorker' in navigator) {
  window.addEventListener('load', () => {
    navigator.serviceWorker.register('/sw.js')
      .then((registration) => {
        console.log('SW registered: ', registration);
        // Preload video after SW is ready
        if (registration.active) {
          registration.active.postMessage({
            type: 'PRELOAD_VIDEO',
            url: '/boucle_fond.webm'
          });
        }
      })
      .catch((registrationError) => {
        console.log('SW registration failed: ', registrationError);
      });
  });
}

createRoot(document.getElementById('root')).render(
  <StrictMode>
    <RouterProvider router={router} />
  </StrictMode>,
)
